package com.mortals.xhx.module.business.service.impl;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.ap.GlobalSysInfo;
import com.mortals.framework.common.code.ExcuteStatus;
import com.mortals.framework.common.code.TaskExcuteStrategy;
import com.mortals.framework.common.code.TaskInterimExcuteStatus;
import com.mortals.framework.service.ITaskExcuteService;
import com.mortals.framework.springcloud.service.IApplicationStartedService;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.util.StringUtils;
import com.mortals.framework.util.SystemUtil;
import com.mortals.xhx.base.system.task.model.TaskEntity;
import com.mortals.xhx.base.system.task.model.TaskQuery;
import com.mortals.xhx.common.code.HolderIdType;
import com.mortals.xhx.common.code.HolderType;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.pdu.ApplyLogPdu;
import com.mortals.xhx.module.certificate.service.CertificateCatalogService;
import com.mortals.xhx.module.record.service.ApplyLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.business.dao.BusinessLicenseDao;
import com.mortals.xhx.module.business.model.BusinessLicenseEntity;
import com.mortals.xhx.module.business.service.BusinessLicenseService;

import java.time.LocalDateTime;
import java.util.*;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
* BusinessLicenseService
* 营业执照信息 service实现
*
* @author zxfei
* @date 2022-12-12
*/
@Service("businessLicenseService")
public class BusinessLicenseServiceImpl extends AbstractCRUDServiceImpl<BusinessLicenseDao, BusinessLicenseEntity, Long> implements BusinessLicenseService {

    /** 营业执照目录(内资公司)id*/
    @Value("${catalog.business.nzgs:1}")
    private long nzgs;
    /** 营业执照目录(内资分公司)id*/
    @Value("${catalog.business.nzgs:2}")
    private long nzgfs;
    /** 营业执照目录(个人)id*/
    @Value("${catalog.business.personal:3}")
    private long personal;

    /** 营业执照目录(有限责任公司)id*/
    @Value("${catalog.business.liabilityCompany:4}")
    private long liabilityCompany;

    /** 营业执照目录(股份有限公司)id*/
    @Value("${catalog.business.stockCompany:5}")
    private long stockCompany;


    @Autowired
    private ApplyLogService applyLogService;

    @Override
    public void apiSave(BusinessLicenseEntity businessLicenseEntity) {
        businessLicenseEntity.setCreateTime(new Date());
        this.save(businessLicenseEntity);
    }

    @Override
    public void doConversion(BusinessLicenseEntity businessLicenseEntity) {
        ApplyLogPdu applyLogPdu = new ApplyLogPdu();
        Date date = DateUtils.StrToDateTime(businessLicenseEntity.getStartDate(),"yyyy-MM-dd");
        if(date==null){
            date = DateUtils.StrToDateTime(businessLicenseEntity.getStartDate(),"yyyy年MM月dd日");
        }else {
            date = new Date();
        }
        applyLogPdu.setIssueTime(date);
        applyLogPdu.setPickerName(businessLicenseEntity.getProprietorName());
        applyLogPdu.setPickerIDCardNo(businessLicenseEntity.getCredentialsCode());
        applyLogPdu.setHolderIdType(HolderIdType.ID_CARD.getValue());
        applyLogPdu.setHolderName(businessLicenseEntity.getProprietorName());
        applyLogPdu.setHolderIDCardNo(businessLicenseEntity.getCredentialsCode());
        applyLogPdu.setEnterpriseName(businessLicenseEntity.getTypeSizeName());
        applyLogPdu.setPrivateID("https://www.gsxt.gov.cn");
        String catalogType = "";
        if(businessLicenseEntity.getComposingForm().indexOf("内资公司")>0){
            applyLogPdu.setCatalogId(nzgs);
            catalogType = "nzgs";
            applyLogPdu.setCertificateCode(businessLicenseEntity.getCredentialsCode());
            applyLogPdu.setCertificateName(businessLicenseEntity.getTypeSizeName());
            applyLogPdu.setHolderType(HolderType.PERSON.getValue());
        }else if(businessLicenseEntity.getComposingForm().indexOf("内资分公司")>0){
            applyLogPdu.setCatalogId(nzgfs);
            catalogType = "nzgfs";
            applyLogPdu.setCertificateCode(businessLicenseEntity.getCredentialsCode());
            applyLogPdu.setCertificateName(businessLicenseEntity.getTypeSizeName());
            applyLogPdu.setHolderType(HolderType.PERSON.getValue());
        }else if(businessLicenseEntity.getComposingForm().indexOf("个人经营")>0){
            applyLogPdu.setCatalogId(personal);
            catalogType = "personal";
            applyLogPdu.setCertificateCode(businessLicenseEntity.getCredentialsCode());
            applyLogPdu.setCertificateName(businessLicenseEntity.getTypeSizeName());
            applyLogPdu.setHolderType(HolderType.PERSON.getValue());
        }else if(businessLicenseEntity.getComposingForm().indexOf("有限责任公司")>0){
            applyLogPdu.setCatalogId(liabilityCompany);
            catalogType = "liabilityCompany";
            applyLogPdu.setCertificateCode(businessLicenseEntity.getCredentialsCode());
            applyLogPdu.setCertificateName(businessLicenseEntity.getTypeSizeName());
            applyLogPdu.setHolderType(HolderType.LEGAL.getValue());
            //TODO
        }else if(businessLicenseEntity.getComposingForm().indexOf("股份公司")>0){
            applyLogPdu.setCatalogId(stockCompany);
            catalogType = "stockCompany";
            applyLogPdu.setCertificateCode(businessLicenseEntity.getCredentialsCode());
            applyLogPdu.setCertificateName(businessLicenseEntity.getTypeSizeName());
            applyLogPdu.setHolderType(HolderType.LEGAL.getValue());
            //TODO
        }
        if(businessLicenseEntity.getDyZb()==1) {

            switch (catalogType){
                case "nzgs":
                    applyLogPdu.setFormContent(nzgsJson(businessLicenseEntity, 1));
                    break;
                case "nzfgs":
                    applyLogPdu.setFormContent(nzfgsJson(businessLicenseEntity, 1));
                    break;
                case "personal":
                    applyLogPdu.setFormContent(personalJson(businessLicenseEntity, 1));
                    break;
                case "liabilityCompany":
                    applyLogPdu.setFormContent(liabilityCompanyJson(businessLicenseEntity, 1));
                    break;
                case "stockCompany":
                    applyLogPdu.setFormContent(stockCompanyJson(businessLicenseEntity, 1));
                    break;
                default:
                    applyLogPdu.setFormContent(personalJson(businessLicenseEntity, 1));
            }
            applyLogPdu.setCertificateName(applyLogPdu.getCertificateName()+"【营业执照正本】");
        }
        applyLogService.apiSaveApplyLog(applyLogPdu);
        if(businessLicenseEntity.getDyFb()==1){
            applyLogPdu.setFormContent(personalJson(businessLicenseEntity,2));
            applyLogPdu.setCertificateName(applyLogPdu.getCertificateName()+"【营业执照副本】");
        }
        applyLogService.apiSaveApplyLog(applyLogPdu);
    }

    private Map<String,String> dateFromt(String dateStr){
        Map<String,String> dateMap = new HashMap<>();
        Date date = DateUtils.StrToDateTime(dateStr,"yyyy-MM-dd");
        if(date==null){
            date = DateUtils.StrToDateTime(dateStr,"yyyy年MM月dd日");
        }else {
            date = new Date();
        }
        if(date!=null){
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(date);
            int year = calendar.get(Calendar.YEAR);
            int month = calendar.get(Calendar.MONTH)+1;
            int day = calendar.get(Calendar.DAY_OF_MONTH);
            dateMap.put("year",String.valueOf(year));
            dateMap.put("month",String.valueOf(month));
            dateMap.put("day",String.valueOf(day));
        }
        return dateMap;
    }

    /**
     * 营业执照个体
     * @param businessLicenseEntity
     * @param qrCodeType 1正本二维码 2副本二维码
     * @return
     */
    private String personalJson(BusinessLicenseEntity businessLicenseEntity,int qrCodeType){
        JSONObject formContent = new JSONObject();
        formContent.put("i_1_执照编码",businessLicenseEntity.getBusinessLicense());
        formContent.put("i_2_单位名称",businessLicenseEntity.getTypeSizeName());
        formContent.put("i_3_单位类型","个体工商户");
        formContent.put("i_4_经营者名称",businessLicenseEntity.getProprietorName());
        formContent.put("i_5_组成形式",businessLicenseEntity.getComposingForm());
        String zcrq = businessLicenseEntity.getStartDate();
        if(StringUtils.isNotEmpty(businessLicenseEntity.getEndDate())){
            zcrq=zcrq+"  至  "+businessLicenseEntity.getEndDate();
        }else {
            zcrq=zcrq+"  至  长期";
        }
        formContent.put("i_6_注册日期",zcrq);
        formContent.put("i_7_经营场所",businessLicenseEntity.getManageLocation());
        formContent.put("i_8_登记机关","某某某市场监督管理局");
        formContent.put("i_9_年",dateFromt(businessLicenseEntity.getStartDate()).get("year"));
        formContent.put("i_10_月",dateFromt(businessLicenseEntity.getStartDate()).get("month"));
        formContent.put("i_11_日",dateFromt(businessLicenseEntity.getStartDate()).get("day"));
        formContent.put("t_1_经营范围",businessLicenseEntity.getManageRange());
        if(qrCodeType==1) {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeOriginalBase64());
        }else {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeDuplicateBase64());
        }
        return formContent.toJSONString();
    }

    /***
     * 内资公司
     * @param businessLicenseEntity
     * @param qrCodeType
     * @return
     */
    private String nzgsJson(BusinessLicenseEntity businessLicenseEntity,int qrCodeType){
        JSONObject formContent = new JSONObject();
        formContent.put("i_1_信用代码",businessLicenseEntity.getBusinessLicense());
        formContent.put("i_2_单位名称",businessLicenseEntity.getTypeSizeName());
        formContent.put("i_3_单位类型",businessLicenseEntity.getComposingForm());
        formContent.put("i_4_法定代表人",businessLicenseEntity.getProprietorName());
        formContent.put("i_10_注册资本",businessLicenseEntity.getRegisteredCapital());
        String zcrq = businessLicenseEntity.getStartDate();
        formContent.put("i_5_成立日期",zcrq);
        formContent.put("i_6_住所",businessLicenseEntity.getManageLocation());
        //formContent.put("i_8_登记机关","某某某市场监督管理局");
        formContent.put("i_7_年",dateFromt(businessLicenseEntity.getStartDate()).get("year"));
        formContent.put("i_8_月",dateFromt(businessLicenseEntity.getStartDate()).get("month"));
        formContent.put("i_9_日",dateFromt(businessLicenseEntity.getStartDate()).get("day"));
        formContent.put("t_1_经营范围",businessLicenseEntity.getManageRange());
        if(qrCodeType==1) {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeOriginalBase64());
        }else {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeDuplicateBase64());
        }
        return formContent.toJSONString();
    }

    /***
     * 内资分公司
     * @param businessLicenseEntity
     * @param qrCodeType
     * @return
     */
    private String nzfgsJson(BusinessLicenseEntity businessLicenseEntity,int qrCodeType){
        JSONObject formContent = new JSONObject();
        formContent.put("i_1_信用代码",businessLicenseEntity.getBusinessLicense());
        formContent.put("i_2_单位名称",businessLicenseEntity.getTypeSizeName());
        formContent.put("i_3_单位类型",businessLicenseEntity.getComposingForm());
        formContent.put("i_4_负责人",businessLicenseEntity.getProprietorName());

        String zcrq = businessLicenseEntity.getStartDate();
        formContent.put("i_5_成立日期",zcrq);
        formContent.put("i_6_经营场所",businessLicenseEntity.getManageLocation());
        //formContent.put("i_8_登记机关","某某某市场监督管理局");
        formContent.put("i_7_年",dateFromt(businessLicenseEntity.getStartDate()).get("year"));
        formContent.put("i_8_月",dateFromt(businessLicenseEntity.getStartDate()).get("month"));
        formContent.put("i_9_日",dateFromt(businessLicenseEntity.getStartDate()).get("day"));
        formContent.put("t_1_经营范围",businessLicenseEntity.getManageRange());
        if(qrCodeType==1) {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeOriginalBase64());
        }else {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeDuplicateBase64());
        }
        return formContent.toJSONString();
    }

    /**
     * 营业执照(有限责任公司)
     * @param businessLicenseEntity
     * @param qrCodeType 1正本二维码 2副本二维码
     * @return
     */
    private String liabilityCompanyJson(BusinessLicenseEntity businessLicenseEntity,int qrCodeType){
        JSONObject formContent = new JSONObject();
        formContent.put("i_1_执照编码",businessLicenseEntity.getBusinessLicense());
        formContent.put("i_2_单位名称",businessLicenseEntity.getTypeSizeName());
        formContent.put("i_3_单位类型","有限责任公司");
        formContent.put("i_4_法定代表人",businessLicenseEntity.getProprietorName());
        formContent.put("i_5_组成形式",businessLicenseEntity.getComposingForm());
        String zcrq = businessLicenseEntity.getStartDate();
        if(StringUtils.isNotEmpty(businessLicenseEntity.getEndDate())){
            zcrq=zcrq+"  至  "+businessLicenseEntity.getEndDate();
        }else {
            zcrq=zcrq+"  至  长期";
        }
        formContent.put("i_6_注册日期",zcrq);
        formContent.put("i_7_经营场所",businessLicenseEntity.getManageLocation());
        formContent.put("i_8_登记机关","某某某市场监督管理局");
        formContent.put("i_9_年",dateFromt(businessLicenseEntity.getStartDate()).get("year"));
        formContent.put("i_10_月",dateFromt(businessLicenseEntity.getStartDate()).get("month"));
        formContent.put("i_11_日",dateFromt(businessLicenseEntity.getStartDate()).get("day"));
        formContent.put("t_1_经营范围",businessLicenseEntity.getManageRange());
        if(qrCodeType==1) {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeOriginalBase64());
        }else {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeDuplicateBase64());
        }
        return formContent.toJSONString();
    }

    /**
     * 营业执照(股份有限公司)
     * @param businessLicenseEntity
     * @param qrCodeType 1正本二维码 2副本二维码
     * @return
     */
    private String stockCompanyJson(BusinessLicenseEntity businessLicenseEntity,int qrCodeType){
        JSONObject formContent = new JSONObject();
        formContent.put("i_1_执照编码",businessLicenseEntity.getBusinessLicense());
        formContent.put("i_2_单位名称",businessLicenseEntity.getTypeSizeName());
        formContent.put("i_3_单位类型","个体工商户");
        formContent.put("i_4_经营者名称",businessLicenseEntity.getProprietorName());
        formContent.put("i_5_组成形式",businessLicenseEntity.getComposingForm());
        String zcrq = businessLicenseEntity.getStartDate();
        if(StringUtils.isNotEmpty(businessLicenseEntity.getEndDate())){
            zcrq=zcrq+"  至  "+businessLicenseEntity.getEndDate();
        }else {
            zcrq=zcrq+"  至  长期";
        }
        formContent.put("i_6_注册日期",zcrq);
        formContent.put("i_7_经营场所",businessLicenseEntity.getManageLocation());
        formContent.put("i_8_登记机关","某某某市场监督管理局");
        formContent.put("i_9_年",dateFromt(businessLicenseEntity.getStartDate()).get("year"));
        formContent.put("i_10_月",dateFromt(businessLicenseEntity.getStartDate()).get("month"));
        formContent.put("i_11_日",dateFromt(businessLicenseEntity.getStartDate()).get("day"));
        formContent.put("t_1_经营范围",businessLicenseEntity.getManageRange());
        if(qrCodeType==1) {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeOriginalBase64());
        }else {
            formContent.put("@image_1_二维码", businessLicenseEntity.getQrCodeDuplicateBase64());
        }
        return formContent.toJSONString();
    }

}