package com.mortals.xhx.module.certificate.service.impl;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.common.code.ClassifyType;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.certificate.dao.CertificateCatalogDao;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.model.CertificateClassifyEntity;
import com.mortals.xhx.module.certificate.service.CertificateCatalogService;
import com.mortals.xhx.module.certificate.service.CertificateClassifyService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.List;


/**
* CertificateCatalogService
* 证照目录 service实现
*
* @author zxfei
* @date 2022-10-14
*/
@Service("certificateCatalogService")
public class CertificateCatalogServiceImpl extends AbstractCRUDServiceImpl<CertificateCatalogDao, CertificateCatalogEntity, Long> implements CertificateCatalogService {

    @Value("${upload.path}")
    private String filePath;

    @Value("${upload.url:http://192.168.0.98:17216/cpm/file/commonupload?prePath=/file/uploadfile}")
    private String uploadUrl;

    @Value("${qrcode.url:http://rhpt.scjg.chengdu.gov.cn:8091/adap/spjy/process/generateQrCode.do?dto.applyId=}")
    private String qrcode;

    @Autowired
    private CertificateClassifyService certificateClassifyService;

    @Override
    protected void saveBefore(CertificateCatalogEntity entity, Context context) throws AppException {
        if(StringUtils.isEmpty(entity.getCatalogName())){
            throw new AppException("目录名称不能为空");
        }
        if(StringUtils.isEmpty(entity.getCatalogCode())){
            throw new AppException("目录编码不能为空");
        }
        if(entity.getHolderType()==null){
            throw new AppException("持有者类型不能为空");
        }
        if(entity.getClassifyId()==null){
            throw new AppException("目录分类不能为空");
        }
        if(entity.getIndustryId()==null){
            throw new AppException("所属行业不能为空");
        }

    }

    @Override
    protected void updateBefore(CertificateCatalogEntity entity, Context context) throws AppException {
        if(StringUtils.isEmpty(entity.getCatalogName())){
            throw new AppException("目录名称不能为空");
        }
        if(StringUtils.isEmpty(entity.getCatalogCode())){
            throw new AppException("目录编码不能为空");
        }
        if(entity.getHolderType()==null){
            throw new AppException("持有者类型不能为空");
        }
        if(entity.getClassifyId()==null){
            throw new AppException("目录分类不能为空");
        }
        if(entity.getIndustryId()==null){
            throw new AppException("所属行业不能为空");
        }

    }


    @Override
    protected CertificateCatalogEntity findBefore(CertificateCatalogEntity params, PageInfo pageInfo, Context context) throws AppException {
        if(StringUtils.isNotEmpty(params.getCatalogName())){
            params.setCatalogName("%".concat(params.getCatalogName()).concat("%"));
        }
        return params;
    }

    @Override
    protected void findAfter(CertificateCatalogEntity params, PageInfo pageInfo, Context context, List<CertificateCatalogEntity> list) throws AppException {
        if(CollectionUtils.isNotEmpty(list)){
            for(CertificateCatalogEntity entity:list){
                CertificateClassifyEntity certificateClassifyEntity = certificateClassifyService.get(entity.getClassifyId());
                if(certificateClassifyEntity!=null){
                    entity.setClassifyType(certificateClassifyEntity.getClassifyType());
                }else {
                    entity.setClassifyType(ClassifyType.PRINCIPAL.getValue());
                }
            }
        }
    }


    public static void  main(String[] args){
//        String excelFilePath = "D:/mortals/app/data/cpm/" + "excel/test1.xls";
//        List<String> excelList = new ArrayList<>();
//        excelList.add("i_1_姓名");
//        excelList.add("i_2_性别");
//        excelList.add("i_3_年龄");
//        excelList.add("i_4_证件编号");
//        excelList.add("i_5_证件名称");
//
//        ExcelUtil.createCatalogTemplate(excelFilePath,excelList);
    }

    @Override
    public void generateExcel(Long id, Context context) {
//        CertificateCatalogEntity entity = dao.get(id);
//        parseDocxToJson(entity,true);
//        CertificateCatalogEntity updata = new CertificateCatalogEntity();
//        updata.setId(entity.getId());
//        updata.setExcelFile(entity.getExcelFile());
//        updata.setUpdateTime(new Date());
//        dao.update(updata);
    }
}